@@ -17,7 +17,7 @@ import sys
 
 from flask import Markup, current_app, request, url_for
 
-__version__ = "2021.10.26"
+__version__ = "2022.01.08"
 
 PY2 = sys.version_info[0] == 2
 
@@ -320,9 +320,9 @@ class Pagination(object):
             **show_single_page**: decide whether or not a single page \
             returns pagination
 
-            **bs_version**: the version of bootstrap, default is **2**
+            **bs_version**: the version of bootstrap, default is **4**
 
-            **css_framework**: the css framework, default is **bootstrap**
+            **css_framework**: the css framework, default is **bootstrap4**
 
             **anchor**: anchor parameter, appends to page href
 
@@ -372,18 +372,30 @@ class Pagination(object):
         if self.css_framework not in CURRENT_PAGES:
             self.css_framework = "bootstrap4"
 
-        self.bs_version = kwargs.get("bs_version") or 4
         if self.css_framework.startswith("bootstrap"):
-            if self.bs_version in (2, "2"):
-                self.css_framework = "bootstrap"
-            elif self.bs_version in (3, "3"):
-                self.css_framework = "bootstrap3"
-            elif self.bs_version in ("3.3", "3_3"):
-                self.css_framework = "bootstrap3_3"
-            elif self.bs_version in (4, "4"):
-                self.css_framework = "bootstrap4"
-            elif self.bs_version in (5, "5"):
-                self.css_framework = "bootstrap5"
+            bs_version = self.css_framework[9:]
+            if bs_version in ("3_3", "3.3"):
+                self.bs_version = "3.3"
+            elif bs_version:
+                self.bs_version = bs_version
+            else:
+                self.bs_version = kwargs.get("bs_version", 4)
+                if self.bs_version in (2, "2"):
+                    self.css_framework = "bootstrap"
+                elif self.bs_version in (3, "3"):
+                    self.css_framework = "bootstrap3"
+                elif self.bs_version in ("3.3", "3_3"):
+                    self.css_framework = "bootstrap3_3"
+                elif self.bs_version in (4, "4"):
+                    self.css_framework = "bootstrap4"
+                elif self.bs_version in (5, "5"):
+                    self.css_framework = "bootstrap5"
+
+            if not isinstance(self.bs_version, int):
+                if self.bs_version.isdigit():
+                    self.bs_version = int(self.bs_version)
+                else:
+                    self.bs_version = float(self.bs_version)
 
         self.link_size = kwargs.get("link_size", "")
         if self.link_size:
